# Disclaimer

I do not own any of the code in this subdirectory. This code is compiled from the `pokemon-showdown-client` git. This code was mostly created by and is mainted by the Pokémon Showdown Staff. Metagrok contributed the code for `engine.js`, `cycle.js`and most of `predef.js`
